@@ -1,4 +1,4 @@
-/* Copyright (c) 2006-2015 Jonas Fonseca <jonas.fonseca@gmail.com>
+/* Copyright (c) 2006-2022 Jonas Fonseca <jonas.fonseca@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -44,15 +44,16 @@
 	REQ_(STATUS_REVERT,	"Revert chunk or file changes"), \
 	REQ_(STATUS_MERGE,	"Merge file using external tool"), \
 	REQ_(STAGE_UPDATE_LINE,	"Stage/unstage single line"), \
+	REQ_(STAGE_UPDATE_PART, "Stage/unstage part of a chunk"), \
 	REQ_(STAGE_SPLIT_CHUNK,	"Split current diff chunk"), \
 	\
 	REQ_GROUP("Cursor navigation") \
 	REQ_(MOVE_UP,		"Move cursor one line up"), \
 	REQ_(MOVE_DOWN,		"Move cursor one line down"), \
+	REQ_(MOVE_PAGE_UP,	"Move cursor one page up"), \
 	REQ_(MOVE_PAGE_DOWN,	"Move cursor one page down"), \
-	REQ_(MOVE_PAGE_UP,	"Move cursor half a page up"), \
+	REQ_(MOVE_HALF_PAGE_UP,	"Move cursor half a page up"), \
 	REQ_(MOVE_HALF_PAGE_DOWN,	"Move cursor half a page down"), \
-	REQ_(MOVE_HALF_PAGE_UP,	"Move cursor one page up"), \
 	REQ_(MOVE_FIRST_LINE,	"Move cursor to first line"), \
 	REQ_(MOVE_LAST_LINE,	"Move cursor to last line"), \
 	REQ_(MOVE_NEXT_MERGE,	"Move cursor to next merge commit"), \
@@ -63,6 +64,8 @@
 	REQ_(SCROLL_LINE_DOWN,	"Scroll one line down"), \
 	REQ_(SCROLL_PAGE_UP,	"Scroll one page up"), \
 	REQ_(SCROLL_PAGE_DOWN,	"Scroll one page down"), \
+	REQ_(SCROLL_HALF_PAGE_UP,	"Scroll half a page up"), \
+	REQ_(SCROLL_HALF_PAGE_DOWN,	"Scroll half a page down"), \
 	REQ_(SCROLL_FIRST_COL,	"Scroll to the first line columns"), \
 	REQ_(SCROLL_LEFT,	"Scroll two columns left"), \
 	REQ_(SCROLL_RIGHT,	"Scroll two columns right"), \
