@@ -1,4 +1,4 @@
-/* Copyright (c) 2006-2015 Jonas Fonseca <jonas.fonseca@gmail.com>
+/* Copyright (c) 2006-2022 Jonas Fonseca <jonas.fonseca@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -30,13 +30,16 @@ enum watch_trigger {
 	WATCH_INDEX_STAGED_NO		= 1 << 1,
 	WATCH_INDEX_UNSTAGED_YES	= 1 << 2,
 	WATCH_INDEX_UNSTAGED_NO		= 1 << 3,
-	WATCH_HEAD			= 1 << 4,
-	WATCH_STASH			= 1 << 5,
-	WATCH_REFS			= 1 << 6,
+	WATCH_INDEX_UNTRACKED_YES	= 1 << 4,
+	WATCH_INDEX_UNTRACKED_NO	= 1 << 5,
+	WATCH_HEAD			= 1 << 6,
+	WATCH_STASH			= 1 << 7,
+	WATCH_REFS			= 1 << 8,
 
 	WATCH_INDEX_STAGED = WATCH_INDEX_STAGED_YES | WATCH_INDEX_STAGED_NO,
 	WATCH_INDEX_UNSTAGED = WATCH_INDEX_UNSTAGED_YES | WATCH_INDEX_UNSTAGED_NO,
-	WATCH_INDEX = WATCH_INDEX_STAGED | WATCH_INDEX_UNSTAGED,
+	WATCH_INDEX_UNTRACKED = WATCH_INDEX_UNTRACKED_YES | WATCH_INDEX_UNTRACKED_NO,
+	WATCH_INDEX = WATCH_INDEX_STAGED | WATCH_INDEX_UNSTAGED | WATCH_INDEX_UNTRACKED,
 };
 
 struct watch {
