@@ -1,4 +1,4 @@
-/* Copyright (c) 2006-2015 Jonas Fonseca <jonas.fonseca@gmail.com>
+/* Copyright (c) 2006-2022 Jonas Fonseca <jonas.fonseca@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -206,6 +206,17 @@ argv_contains(const char **argv, const char *arg)
 	return false;
 }
 
+bool
+argv_containsn(const char **argv, const char *arg, size_t arglen)
+{
+	int i;
+
+	for (i = 0; argv && argv[i]; i++)
+		if (!strncmp(argv[i], arg, arglen))
+			return true;
+	return false;
+}
+
 DEFINE_ALLOCATOR(argv_realloc, const char *, SIZEOF_ARG)
 
 bool
@@ -337,18 +348,19 @@ format_append_arg(struct format_context *format, const char ***dst_argv, const c
 
 	while (arg) {
 		const char *var = strstr(arg, "%(");
-		const char *esc = var > arg && *(var - 1) == '%' ? var - 1 : NULL;
-		const char *closing = var ? strchr(var, ')') : NULL;
-		const char *next = esc > arg ? esc : closing ? closing + 1 : NULL;
-		const int len = var && !esc ? var - arg : esc > arg ? esc - arg : next ? next - ++arg : strlen(arg);
+		const char *esc = strstr(arg, "%%");
+		bool is_escaped = esc && (esc < var || !var);
+		const char *closing = var && !is_escaped ? strchr(var, ')') : NULL;
+		const char *next = is_escaped ? esc + 2 : closing ? closing + 1 : NULL;
+		int len = var && !is_escaped ? var - arg : esc ? esc - arg + 1 : strlen(arg);
 
-		if (var && !closing)
+		if (var && !is_escaped && !closing)
 			return false;
 
 		if (len && !string_format_from(format->buf, &format->bufpos, "%.*s", len, arg))
 			return false;
 
-		if (var && !esc && !format_expand_arg(format, var, next))
+		if (var && !is_escaped && !format_expand_arg(format, var, next))
 			return false;
 
 		arg = next;
