@@ -1,4 +1,4 @@
-/* Copyright (c) 2006-2015 Jonas Fonseca <jonas.fonseca@gmail.com>
+/* Copyright (c) 2006-2022 Jonas Fonseca <jonas.fonseca@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -584,7 +584,7 @@ diff_blame_line(const char *ref, const char *file, unsigned long lineno,
 
 	while (io_get(&io, &buf, '\n', true)) {
 		if (header) {
-			if (!parse_blame_header(header, buf.data, 9999999))
+			if (!parse_blame_header(header, buf.data))
 				break;
 			header = NULL;
 
@@ -719,7 +719,7 @@ diff_get_pathname(struct view *view, struct line *line, bool old)
 	const char *name;
 	int i;
 
-	header = find_prev_line_by_type(view, line, LINE_DIFF_HEADER);
+	header = find_prev_line_in_commit_by_type(view, line, LINE_DIFF_HEADER);
 	if (!header)
 		return NULL;
 
@@ -811,6 +811,8 @@ diff_common_select(struct view *view, struct line *line, const char *changes_msg
 				const char *old_file = diff_get_pathname(view, header, true);
 				if (old_file)
 					string_format(view->env->file_old, "%s", old_file);
+				else
+					view->env->file_old[0] = '\0';
 				string_format(view->env->file, "%s", file);
 				view->env->lineno = view->env->goto_lineno = 0;
 				view->env->blob[0] = 0;
@@ -826,6 +828,8 @@ diff_common_select(struct view *view, struct line *line, const char *changes_msg
 			const char *old_file = diff_get_pathname(view, line, true);
 			if (old_file)
 				string_format(view->env->file_old, "%s", old_file);
+			else
+				view->env->file_old[0] = '\0';
 			if (changes_msg)
 				string_format(view->ref, "%s to '%s'", changes_msg, file);
 			string_format(view->env->file, "%s", file);
@@ -835,6 +839,7 @@ diff_common_select(struct view *view, struct line *line, const char *changes_msg
 			view->env->lineno_old = diff_get_lineno(view, line, true);
 			view->env->blob[0] = 0;
 		} else {
+			view->env->lineno = view->env->goto_lineno = (line - view->line) + 1;
 			string_ncopy(view->ref, view->ops->id, strlen(view->ops->id));
 		}
 	}
