@@ -90,6 +90,9 @@ log_request(struct view *view, enum request request, struct line *line)
 		refresh_view(view);
 		return REQ_NONE;
 
+	case REQ_EDIT:
+		return diff_common_edit(view, request, line);
+
 	case REQ_ENTER:
 		if (!display[1] || strcmp(display[1]->vid, view->ref))
 			open_diff_view(view, flags);
@@ -129,7 +132,7 @@ log_read(struct view *view, struct buffer *buf, bool force_stop)
 	else if (state->commit_title_read && len < 1) {
 		state->commit_title_read = false;
 		state->after_commit_header = true;
-	} else if (state->after_commit_header && len < 1) {
+	} else if ((state->after_commit_header && len < 1) || type == LINE_DIFF_START) {
 		state->after_commit_header = false;
 		state->reading_diff_stat = true;
 	} else if (state->reading_diff_stat) {
