@@ -1,4 +1,4 @@
-/* Copyright (c) 2006-2015 Jonas Fonseca <jonas.fonseca@gmail.com>
+/* Copyright (c) 2006-2022 Jonas Fonseca <jonas.fonseca@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -134,9 +134,12 @@ pager_common_read(struct view *view, const char *data, enum line_type type, stru
 	return true;
 }
 
-bool
+static bool
 pager_read(struct view *view, struct buffer *buf, bool force_stop)
 {
+	if (opt_pager_autoscroll && view->pos.offset + view->height == view->lines - 1)
+		do_scroll_view(view, 1);
+
 	if (!buf) {
 		if (!diff_done_highlight(view->private)) {
 			report("Failed run the diff-highlight program: %s", opt_diff_highlight);
@@ -155,6 +158,9 @@ pager_request(struct view *view, enum request request, struct line *line)
 	enum open_flags flags = view_is_displayed(view) ? OPEN_SPLIT : OPEN_DEFAULT;
 	int split = 0;
 
+	if (request == REQ_EDIT)
+		return diff_common_edit(view, request, line);
+
 	if (request != REQ_ENTER)
 		return request;
 
