@@ -1,4 +1,4 @@
-/* Copyright (c) 2006-2015 Jonas Fonseca <jonas.fonseca@gmail.com>
+/* Copyright (c) 2006-2022 Jonas Fonseca <jonas.fonseca@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -60,38 +60,6 @@
 #include <pcre.h>
 #endif
 
-static bool
-forward_request_to_child(struct view *child, enum request request)
-{
-	return displayed_views() == 2 && view_is_displayed(child) &&
-		!strcmp(child->vid, child->ops->id);
-}
-
-static enum request
-view_request(struct view *view, enum request request)
-{
-	if (!view || !view->lines)
-		return request;
-
-	if (request == REQ_ENTER && view == display[0] &&
-	    !opt_focus_child && opt_send_child_enter &&
-	    view_has_flags(view, VIEW_SEND_CHILD_ENTER)) {
-		struct view *child = display[1];
-
-		if (forward_request_to_child(child, request)) {
-			view_request(child, request);
-			return REQ_NONE;
-		}
-	}
-
-	if (request == REQ_REFRESH && !view_can_refresh(view)) {
-		report("This view can not be refreshed");
-		return REQ_NONE;
-	}
-
-	return view->ops->request(view, request, &view->line[view->pos.lineno]);
-}
-
 /*
  * Option management
  */
@@ -261,7 +229,9 @@ view_driver(struct view *view, enum request request)
 			move_view(parent, request);
 			if (view_is_displayed(parent))
 				update_view_title(parent);
-			if (line != parent->pos.lineno) {
+			if (line != parent->pos.lineno &&
+			    !(parent == &tree_view && 
+			      parent->line[parent->pos.lineno].type == LINE_DIRECTORY)) {
 				end_update(view, true);
 				view_request(parent, REQ_ENTER);
 			}
@@ -354,6 +324,7 @@ view_driver(struct view *view, enum request request)
 		 * view itself. Parents to closed view should never be
 		 * followed. */
 		if (view->prev && view->prev != view) {
+			end_update(view, true);
 			maximize_view(view->prev, true);
 			view->prev = view;
 			break;
@@ -364,6 +335,8 @@ view_driver(struct view *view, enum request request)
 		}
 		/* Fall-through */
 	case REQ_QUIT:
+		foreach_view(view, i)
+			end_update(view, true);
 		return false;
 
 	default:
@@ -555,7 +528,7 @@ parse_options(int argc, const char *argv[], bool pager_mode)
 				printf("tig version %s\n", TIG_VERSION);
 #ifdef NCURSES_VERSION
 				printf("%s version %s.%d\n",
-#ifdef NCURSES_WIDECHAR
+#if defined(HAVE_NCURSESW_CURSES_H) || defined(HAVE_NCURSESW_H)
 				       "ncursesw",
 #else
 				       "ncurses",
