@@ -4,7 +4,7 @@
 #
 # Usage: $0 {data|bin} src dest
 #
-# Copyright (c) 2014 Jonas Fonseca <jonas.fonseca@gmail.com>
+# Copyright (c) 2006-2022 Jonas Fonseca <jonas.fonseca@gmail.com>
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License as
@@ -28,7 +28,7 @@ case "$data" in data)
 	mode=0644
 esac
 
-mkdir -p "$dest"
+install -d "$dest"
 
 if [ "$V" = "@" ]; then
 	echo "$src -> $dest"
